/* 
 * $Id: ftp_command.h,v 1.4 2000/03/16 14:34:18 shane Exp $
 *
 * The following comands are parsed:
 *
 * USER <SP> <username>
 * PASS <SP> <password>
 * CWD  <SP> <pathname> 
 * CDUP
 * QUIT
 * PORT <SP> <host-port>
 * PASV
 * TYPE <SP> <type-code>
 * STRU <SP> <structure-code>
 * MODE <SP> <mode-code>
 * RETR <SP> <pathname>
 * STOR <SP> <pathname>
 * PWD
 * LIST [ <SP> <pathname> ]
 * NLST [ <SP> <pathname> ]
 * SYST
 * HELP [ <SP> <string> ]
 * NOOP
 * REST <SP> <offset>
 */

#ifndef FTP_COMMAND_H
#define FTP_COMMAND_H

#include <netinet/in.h>
#include <limits.h>
#include <sys/types.h>

/* maximum possible number of arguments */
#define MAX_ARG 2

/* maximum string length */
#define MAX_STRING_LEN PATH_MAX

typedef struct {
    char command[5];
    int num_arg;
    union {
        char string[MAX_STRING_LEN+1];
        struct sockaddr_in host_port;
        int num;
	off_t offset;
    } arg[MAX_ARG];
} ftp_command_t;

int ftp_command_parse(const char *input, ftp_command_t *cmd);

#endif /* FTP_COMMAND_H */

